.. _api_exceptions:

==========
Exceptions
==========

.. contents::

vcfpy.VCFPyException
--------------------

.. autoexception:: vcfpy.VCFPyException
    :members:

vcfpy.InvalidHeaderException
----------------------------

.. autoexception:: vcfpy.InvalidHeaderException
    :members:

vcfpy.InvalidRecordException
----------------------------

.. autoexception:: vcfpy.InvalidRecordException
    :members:

vcfpy.IncorrectVCFFormat
------------------------

.. autoexception:: vcfpy.IncorrectVCFFormat
    :members:

vcfpy.HeaderNotFound
--------------------

.. autoexception:: vcfpy.HeaderNotFound
    :members:
